==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/GovernanceBundleLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GovernanceBundleLinks
 */
@JsonPropertyOrder({ GovernanceBundleLinks.JSON_PROPERTY_ENTITLEMENTS })
@JsonTypeName("GovernanceBundle__links")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class GovernanceBundleLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENTITLEMENTS = "entitlements";
    private HrefObject entitlements;

    public GovernanceBundleLinks() {
    }

    public GovernanceBundleLinks entitlements(HrefObject entitlements) {

        this.entitlements = entitlements;
        return this;
    }

    /**
     * Get entitlements
     *
     * @return entitlements
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getEntitlements() {
        return entitlements;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlements(HrefObject entitlements) {
        this.entitlements = entitlements;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GovernanceBundleLinks governanceBundleLinks = (GovernanceBundleLinks) o;
        return Objects.equals(this.entitlements, governanceBundleLinks.entitlements);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(entitlements);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GovernanceBundleLinks {\n");
        sb.append("    entitlements: ").append(toIndentedString(entitlements)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/GovernanceBundleLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * GovernanceBundleLinks
 */
@JsonPropertyOrder({ GovernanceBundleLinks.JSON_PROPERTY_ENTITLEMENTS })
@JsonTypeName("GovernanceBundle__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class GovernanceBundleLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENTITLEMENTS = "entitlements";
    private HrefObject entitlements;

    public GovernanceBundleLinks() {
    }

    public GovernanceBundleLinks entitlements(HrefObject entitlements) {

        this.entitlements = entitlements;
        return this;
    }

    /**
     * Get entitlements
     *
     * @return entitlements
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getEntitlements() {
        return entitlements;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlements(HrefObject entitlements) {
        this.entitlements = entitlements;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        GovernanceBundleLinks governanceBundleLinks = (GovernanceBundleLinks) o;
        return Objects.equals(this.entitlements, governanceBundleLinks.entitlements);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(entitlements);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class GovernanceBundleLinks {\n");
        sb.append("    entitlements: ").append(toIndentedString(entitlements)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
